

=======
Sources
=======

Libraries
---------

* PyNLPl: `Github <https://github.com/proycon/pynlpl>`_ and `API Documentation
  <http://pynlpl.readthedocs.io/en/latest/>`_, pronounced as 'pineapple', is a Python
  library for Natural Language Processing. It contains various modules useful for common, and
  less common, NLP tasks. PyNLPl contains modules for basic tasks, clients for interfacting
  with server, and modules for parsing several file formats common in NLP, most notably FoLiA.

Books
-----

* `Foundations of Statistical Natural Language Processing <https://nlp.stanford.edu/fsnlp/>`_
* `Speech and Language Processing <http://www.cs.colorado.edu/~martin/slp.html>`_,
  An Introduction to Natural Language Processing, Computational Linguistics, and Speech Recognition
